==> mysql-8.0_8.0.28.orig.tar.gz: mysql-8.0.28/unittest/gunit/mysys_my_malloc-t.cc <==
/* Copyright (c) 2010, 2021, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#include <gtest/gtest.h>
#include <mysql/service_mysql_alloc.h>
#include <stddef.h>

#include "my_inttypes.h"
#include "my_sys.h"

namespace mysys_my_malloc_unittest {

TEST(Mysys, Malloc) {
  void *p;

  p = my_malloc(PSI_NOT_INSTRUMENTED, 0, MYF(0));
  EXPECT_TRUE(p != nullptr) << "Zero-sized block allocation.";

  p = my_realloc(PSI_NOT_INSTRUMENTED, p, 32, MYF(0));
  EXPECT_TRUE(p != nullptr) << "Reallocated zero-sized block.";

  p = my_realloc(PSI_NOT_INSTRUMENTED, p, 16, MYF(0));
  EXPECT_TRUE(p != nullptr) << "Trimmed block.";

  my_free(p);
  p = nullptr;

  my_free(p);
}

}  // namespace mysys_my_malloc_unittest

==> mysql-8.4_8.4.6.orig.tar.gz: mysql-8.4.6/unittest/gunit/mysys_my_malloc-t.cc <==
/* Copyright (c) 2010, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#include <gtest/gtest.h>
#include <mysql/service_mysql_alloc.h>
#include <stddef.h>

#include "my_inttypes.h"
#include "my_sys.h"

namespace mysys_my_malloc_unittest {

TEST(Mysys, Malloc) {
  void *p;

  p = my_malloc(PSI_NOT_INSTRUMENTED, 0, MYF(0));
  EXPECT_TRUE(p != nullptr) << "Zero-sized block allocation.";

  p = my_realloc(PSI_NOT_INSTRUMENTED, p, 32, MYF(0));
  EXPECT_TRUE(p != nullptr) << "Reallocated zero-sized block.";

  p = my_realloc(PSI_NOT_INSTRUMENTED, p, 16, MYF(0));
  EXPECT_TRUE(p != nullptr) << "Trimmed block.";

  my_free(p);
  p = nullptr;

  my_free(p);
}

}  // namespace mysys_my_malloc_unittest
